@@ -5,6 +5,7 @@ import sys
 import unittest
 import warnings
 import textwrap
+import functools
 
 from unittest import mock
 
@@ -42,22 +43,18 @@ class TestDistribution(Distribution):
         return self._config_files
 
 
+@pytest.fixture
+def clear_argv():
+    del sys.argv[1:]
+
+
+@support.combine_markers
 @pytest.mark.usefixtures('save_env')
-class DistributionTestCase(
+@pytest.mark.usefixtures('save_argv')
+class TestDistributionBehavior(
     support.LoggingSilencer,
     support.TempdirManager,
-    unittest.TestCase,
 ):
-    def setUp(self):
-        super(DistributionTestCase, self).setUp()
-        self.argv = sys.argv, sys.argv[:]
-        del sys.argv[1:]
-
-    def tearDown(self):
-        sys.argv = self.argv[0]
-        sys.argv[:] = self.argv[1]
-        super(DistributionTestCase, self).tearDown()
-
     def create_distribution(self, configfiles=()):
         d = TestDistribution()
         d._config_files = configfiles
@@ -65,12 +62,12 @@ class DistributionTestCase(
         d.parse_command_line()
         return d
 
-    def test_command_packages_unspecified(self):
+    def test_command_packages_unspecified(self, clear_argv):
         sys.argv.append("build")
         d = self.create_distribution()
-        self.assertEqual(d.get_command_packages(), ["distutils.command"])
+        assert d.get_command_packages() == ["distutils.command"]
 
-    def test_command_packages_cmdline(self):
+    def test_command_packages_cmdline(self, clear_argv):
         from distutils.tests.test_dist import test_dist
 
         sys.argv.extend(
@@ -83,21 +80,22 @@ class DistributionTestCase(
         )
         d = self.create_distribution()
         # let's actually try to load our test command:
-        self.assertEqual(
-            d.get_command_packages(),
-            ["distutils.command", "foo.bar", "distutils.tests"],
-        )
+        assert d.get_command_packages() == [
+            "distutils.command",
+            "foo.bar",
+            "distutils.tests",
+        ]
         cmd = d.get_command_obj("test_dist")
-        self.assertIsInstance(cmd, test_dist)
-        self.assertEqual(cmd.sample_option, "sometext")
+        assert isinstance(cmd, test_dist)
+        assert cmd.sample_option == "sometext"
 
     @unittest.skipIf(
         'distutils' not in Distribution.parse_config_files.__module__,
         'Cannot test when virtualenv has monkey-patched Distribution.',
     )
-    def test_venv_install_options(self):
+    def test_venv_install_options(self, request):
         sys.argv.append("install")
-        self.addCleanup(os.unlink, TESTFN)
+        request.addfinalizer(functools.partial(os.unlink, TESTFN))
 
         fakepath = '/somedir'
 
@@ -144,23 +142,23 @@ class DistributionTestCase(
             'root': option_tuple,
         }
 
-        self.assertEqual(
-            sorted(d.command_options.get('install').keys()), sorted(result_dict.keys())
+        assert sorted(d.command_options.get('install').keys()) == sorted(
+            result_dict.keys()
         )
 
         for (key, value) in d.command_options.get('install').items():
-            self.assertEqual(value, result_dict[key])
+            assert value == result_dict[key]
 
         # Test case: In a Virtual Environment
         with mock.patch.multiple(sys, prefix='/a', base_prefix='/b'):
             d = self.create_distribution([TESTFN])
 
         for key in result_dict.keys():
-            self.assertNotIn(key, d.command_options.get('install', {}))
+            assert key not in d.command_options.get('install', {})
 
-    def test_command_packages_configfile(self):
+    def test_command_packages_configfile(self, request, clear_argv):
         sys.argv.append("build")
-        self.addCleanup(os.unlink, TESTFN)
+        request.addfinalizer(functools.partial(os.unlink, TESTFN))
         f = open(TESTFN, "w")
         try:
             print("[global]", file=f)
@@ -169,22 +167,20 @@ class DistributionTestCase(
             f.close()
 
         d = self.create_distribution([TESTFN])
-        self.assertEqual(
-            d.get_command_packages(), ["distutils.command", "foo.bar", "splat"]
-        )
+        assert d.get_command_packages() == ["distutils.command", "foo.bar", "splat"]
 
         # ensure command line overrides config:
         sys.argv[1:] = ["--command-packages", "spork", "build"]
         d = self.create_distribution([TESTFN])
-        self.assertEqual(d.get_command_packages(), ["distutils.command", "spork"])
+        assert d.get_command_packages() == ["distutils.command", "spork"]
 
         # Setting --command-packages to '' should cause the default to
         # be used even if a config file specified something else:
         sys.argv[1:] = ["--command-packages", "", "build"]
         d = self.create_distribution([TESTFN])
-        self.assertEqual(d.get_command_packages(), ["distutils.command"])
+        assert d.get_command_packages() == ["distutils.command"]
 
-    def test_empty_options(self):
+    def test_empty_options(self, request):
         # an empty options dictionary should not stay in the
         # list of attributes
 
@@ -194,7 +190,9 @@ class DistributionTestCase(
         def _warn(msg):
             warns.append(msg)
 
-        self.addCleanup(setattr, warnings, 'warn', warnings.warn)
+        request.addfinalizer(
+            functools.partial(setattr, warnings, 'warn', warnings.warn)
+        )
         warnings.warn = _warn
         dist = Distribution(
             attrs={
@@ -206,8 +204,8 @@ class DistributionTestCase(
             }
         )
 
-        self.assertEqual(len(warns), 0)
-        self.assertNotIn('options', dir(dist))
+        assert len(warns) == 0
+        assert 'options' not in dir(dist)
 
     def test_finalize_options(self):
         attrs = {'keywords': 'one,two', 'platforms': 'one,two'}
@@ -216,32 +214,33 @@ class DistributionTestCase(
         dist.finalize_options()
 
         # finalize_option splits platforms and keywords
-        self.assertEqual(dist.metadata.platforms, ['one', 'two'])
-        self.assertEqual(dist.metadata.keywords, ['one', 'two'])
+        assert dist.metadata.platforms == ['one', 'two']
+        assert dist.metadata.keywords == ['one', 'two']
 
         attrs = {'keywords': 'foo bar', 'platforms': 'foo bar'}
         dist = Distribution(attrs=attrs)
         dist.finalize_options()
-        self.assertEqual(dist.metadata.platforms, ['foo bar'])
-        self.assertEqual(dist.metadata.keywords, ['foo bar'])
+        assert dist.metadata.platforms == ['foo bar']
+        assert dist.metadata.keywords == ['foo bar']
 
     def test_get_command_packages(self):
         dist = Distribution()
-        self.assertEqual(dist.command_packages, None)
+        assert dist.command_packages is None
         cmds = dist.get_command_packages()
-        self.assertEqual(cmds, ['distutils.command'])
-        self.assertEqual(dist.command_packages, ['distutils.command'])
+        assert cmds == ['distutils.command']
+        assert dist.command_packages == ['distutils.command']
 
         dist.command_packages = 'one,two'
         cmds = dist.get_command_packages()
-        self.assertEqual(cmds, ['distutils.command', 'one', 'two'])
+        assert cmds == ['distutils.command', 'one', 'two']
 
     def test_announce(self):
         # make sure the level is known
         dist = Distribution()
         args = ('ok',)
         kwargs = {'level': 'ok2'}
-        self.assertRaises(ValueError, dist.announce, args, kwargs)
+        with pytest.raises(ValueError):
+            dist.announce(args, kwargs)
 
     def test_find_config_files_disable(self):
         # Ticket #1180: Allow user to disable their home config file.
@@ -269,20 +268,12 @@ class DistributionTestCase(
             os.path.expanduser = old_expander
 
         # make sure --no-user-cfg disables the user cfg file
-        self.assertEqual(len(all_files) - 1, len(files))
+        assert len(all_files) - 1 == len(files)
 
 
 @pytest.mark.usefixtures('save_env')
-class MetadataTestCase(support.TempdirManager, unittest.TestCase):
-    def setUp(self):
-        super(MetadataTestCase, self).setUp()
-        self.argv = sys.argv, sys.argv[:]
-
-    def tearDown(self):
-        sys.argv = self.argv[0]
-        sys.argv[:] = self.argv[1]
-        super(MetadataTestCase, self).tearDown()
-
+@pytest.mark.usefixtures('save_argv')
+class MetadataTestCase(support.TempdirManager):
     def format_metadata(self, dist):
         sio = io.StringIO()
         dist.metadata.write_pkg_file(sio)
@@ -292,10 +283,10 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
         attrs = {"name": "package", "version": "1.0"}
         dist = Distribution(attrs)
         meta = self.format_metadata(dist)
-        self.assertIn("Metadata-Version: 1.0", meta)
-        self.assertNotIn("provides:", meta.lower())
-        self.assertNotIn("requires:", meta.lower())
-        self.assertNotIn("obsoletes:", meta.lower())
+        assert "Metadata-Version: 1.0" in meta
+        assert "provides:" not in meta.lower()
+        assert "requires:" not in meta.lower()
+        assert "obsoletes:" not in meta.lower()
 
     def test_provides(self):
         attrs = {
@@ -304,19 +295,18 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
             "provides": ["package", "package.sub"],
         }
         dist = Distribution(attrs)
-        self.assertEqual(dist.metadata.get_provides(), ["package", "package.sub"])
-        self.assertEqual(dist.get_provides(), ["package", "package.sub"])
+        assert dist.metadata.get_provides() == ["package", "package.sub"]
+        assert dist.get_provides() == ["package", "package.sub"]
         meta = self.format_metadata(dist)
-        self.assertIn("Metadata-Version: 1.1", meta)
-        self.assertNotIn("requires:", meta.lower())
-        self.assertNotIn("obsoletes:", meta.lower())
+        assert "Metadata-Version: 1.1" in meta
+        assert "requires:" not in meta.lower()
+        assert "obsoletes:" not in meta.lower()
 
     def test_provides_illegal(self):
-        self.assertRaises(
-            ValueError,
-            Distribution,
-            {"name": "package", "version": "1.0", "provides": ["my.pkg (splat)"]},
-        )
+        with pytest.raises(ValueError):
+            Distribution(
+                {"name": "package", "version": "1.0", "provides": ["my.pkg (splat)"]},
+            )
 
     def test_requires(self):
         attrs = {
@@ -325,26 +315,25 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
             "requires": ["other", "another (==1.0)"],
         }
         dist = Distribution(attrs)
-        self.assertEqual(dist.metadata.get_requires(), ["other", "another (==1.0)"])
-        self.assertEqual(dist.get_requires(), ["other", "another (==1.0)"])
+        assert dist.metadata.get_requires() == ["other", "another (==1.0)"]
+        assert dist.get_requires() == ["other", "another (==1.0)"]
         meta = self.format_metadata(dist)
-        self.assertIn("Metadata-Version: 1.1", meta)
-        self.assertNotIn("provides:", meta.lower())
-        self.assertIn("Requires: other", meta)
-        self.assertIn("Requires: another (==1.0)", meta)
-        self.assertNotIn("obsoletes:", meta.lower())
+        assert "Metadata-Version: 1.1" in meta
+        assert "provides:" not in meta.lower()
+        assert "Requires: other" in meta
+        assert "Requires: another (==1.0)" in meta
+        assert "obsoletes:" not in meta.lower()
 
     def test_requires_illegal(self):
-        self.assertRaises(
-            ValueError,
-            Distribution,
-            {"name": "package", "version": "1.0", "requires": ["my.pkg (splat)"]},
-        )
+        with pytest.raises(ValueError):
+            Distribution(
+                {"name": "package", "version": "1.0", "requires": ["my.pkg (splat)"]},
+            )
 
     def test_requires_to_list(self):
         attrs = {"name": "package", "requires": iter(["other"])}
         dist = Distribution(attrs)
-        self.assertIsInstance(dist.metadata.requires, list)
+        assert isinstance(dist.metadata.requires, list)
 
     def test_obsoletes(self):
         attrs = {
@@ -353,26 +342,25 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
             "obsoletes": ["other", "another (<1.0)"],
         }
         dist = Distribution(attrs)
-        self.assertEqual(dist.metadata.get_obsoletes(), ["other", "another (<1.0)"])
-        self.assertEqual(dist.get_obsoletes(), ["other", "another (<1.0)"])
+        assert dist.metadata.get_obsoletes() == ["other", "another (<1.0)"]
+        assert dist.get_obsoletes() == ["other", "another (<1.0)"]
         meta = self.format_metadata(dist)
-        self.assertIn("Metadata-Version: 1.1", meta)
-        self.assertNotIn("provides:", meta.lower())
-        self.assertNotIn("requires:", meta.lower())
-        self.assertIn("Obsoletes: other", meta)
-        self.assertIn("Obsoletes: another (<1.0)", meta)
+        assert "Metadata-Version: 1.1" in meta
+        assert "provides:" not in meta.lower()
+        assert "requires:" not in meta.lower()
+        assert "Obsoletes: other" in meta
+        assert "Obsoletes: another (<1.0)" in meta
 
     def test_obsoletes_illegal(self):
-        self.assertRaises(
-            ValueError,
-            Distribution,
-            {"name": "package", "version": "1.0", "obsoletes": ["my.pkg (splat)"]},
-        )
+        with pytest.raises(ValueError):
+            Distribution(
+                {"name": "package", "version": "1.0", "obsoletes": ["my.pkg (splat)"]},
+            )
 
     def test_obsoletes_to_list(self):
         attrs = {"name": "package", "obsoletes": iter(["other"])}
         dist = Distribution(attrs)
-        self.assertIsInstance(dist.metadata.obsoletes, list)
+        assert isinstance(dist.metadata.obsoletes, list)
 
     def test_classifier(self):
         attrs = {
@@ -381,11 +369,9 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
             'classifiers': ['Programming Language :: Python :: 3'],
         }
         dist = Distribution(attrs)
-        self.assertEqual(
-            dist.get_classifiers(), ['Programming Language :: Python :: 3']
-        )
+        assert dist.get_classifiers() == ['Programming Language :: Python :: 3']
         meta = self.format_metadata(dist)
-        self.assertIn('Metadata-Version: 1.1', meta)
+        assert 'Metadata-Version: 1.1' in meta
 
     def test_classifier_invalid_type(self):
         attrs = {
@@ -396,10 +382,10 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
         with captured_stderr() as error:
             d = Distribution(attrs)
         # should have warning about passing a non-list
-        self.assertIn('should be a list', error.getvalue())
+        assert 'should be a list' in error.getvalue()
         # should be converted to a list
-        self.assertIsInstance(d.metadata.classifiers, list)
-        self.assertEqual(d.metadata.classifiers, list(attrs['classifiers']))
+        assert isinstance(d.metadata.classifiers, list)
+        assert d.metadata.classifiers == list(attrs['classifiers'])
 
     def test_keywords(self):
         attrs = {
@@ -408,7 +394,7 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
             'keywords': ['spam', 'eggs', 'life of brian'],
         }
         dist = Distribution(attrs)
-        self.assertEqual(dist.get_keywords(), ['spam', 'eggs', 'life of brian'])
+        assert dist.get_keywords() == ['spam', 'eggs', 'life of brian']
 
     def test_keywords_invalid_type(self):
         attrs = {
@@ -419,10 +405,10 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
         with captured_stderr() as error:
             d = Distribution(attrs)
         # should have warning about passing a non-list
-        self.assertIn('should be a list', error.getvalue())
+        assert 'should be a list' in error.getvalue()
         # should be converted to a list
-        self.assertIsInstance(d.metadata.keywords, list)
-        self.assertEqual(d.metadata.keywords, list(attrs['keywords']))
+        assert isinstance(d.metadata.keywords, list)
+        assert d.metadata.keywords == list(attrs['keywords'])
 
     def test_platforms(self):
         attrs = {
@@ -431,7 +417,7 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
             'platforms': ['GNU/Linux', 'Some Evil Platform'],
         }
         dist = Distribution(attrs)
-        self.assertEqual(dist.get_platforms(), ['GNU/Linux', 'Some Evil Platform'])
+        assert dist.get_platforms() == ['GNU/Linux', 'Some Evil Platform']
 
     def test_platforms_invalid_types(self):
         attrs = {
@@ -442,10 +428,10 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
         with captured_stderr() as error:
             d = Distribution(attrs)
         # should have warning about passing a non-list
-        self.assertIn('should be a list', error.getvalue())
+        assert 'should be a list' in error.getvalue()
         # should be converted to a list
-        self.assertIsInstance(d.metadata.platforms, list)
-        self.assertEqual(d.metadata.platforms, list(attrs['platforms']))
+        assert isinstance(d.metadata.platforms, list)
+        assert d.metadata.platforms == list(attrs['platforms'])
 
     def test_download_url(self):
         attrs = {
@@ -455,7 +441,7 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
         }
         dist = Distribution(attrs)
         meta = self.format_metadata(dist)
-        self.assertIn('Metadata-Version: 1.1', meta)
+        assert 'Metadata-Version: 1.1' in meta
 
     def test_long_description(self):
         long_desc = textwrap.dedent(
@@ -470,7 +456,7 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
         dist = Distribution(attrs)
         meta = self.format_metadata(dist)
         meta = meta.replace('\n' + 8 * ' ', '\n')
-        self.assertIn(long_desc, meta)
+        assert long_desc in meta
 
     def test_custom_pydistutils(self):
         # fixes #2166
@@ -495,15 +481,15 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
             if sys.platform in ('linux', 'darwin'):
                 os.environ['HOME'] = temp_dir
                 files = dist.find_config_files()
-                self.assertIn(user_filename, files)
+                assert user_filename in files
 
             # win32-style
             if sys.platform == 'win32':
                 # home drive should be found
                 os.environ['USERPROFILE'] = temp_dir
                 files = dist.find_config_files()
-                self.assertIn(
-                    user_filename, files, '%r not found in %r' % (user_filename, files)
+                assert user_filename in files, '{!r} not found in {!r}'.format(
+                    user_filename, files
                 )
         finally:
             os.remove(user_filename)
@@ -511,8 +497,8 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
     def test_fix_help_options(self):
         help_tuples = [('a', 'b', 'c', 'd'), (1, 2, 3, 4)]
         fancy_options = fix_help_options(help_tuples)
-        self.assertEqual(fancy_options[0], ('a', 'b', 'c'))
-        self.assertEqual(fancy_options[1], (1, 2, 3))
+        assert fancy_options[0] == ('a', 'b', 'c')
+        assert fancy_options[1] == (1, 2, 3)
 
     def test_show_help(self):
         # smoke test, just makes sure some help is displayed
@@ -525,7 +511,7 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
             dist.parse_command_line()
 
         output = [line for line in s.getvalue().split('\n') if line.strip() != '']
-        self.assertTrue(output)
+        assert output
 
     def test_read_metadata(self):
         attrs = {
@@ -547,11 +533,11 @@ class MetadataTestCase(support.TempdirManager, unittest.TestCase):
         PKG_INFO.seek(0)
         metadata.read_pkg_file(PKG_INFO)
 
-        self.assertEqual(metadata.name, "package")
-        self.assertEqual(metadata.version, "1.0")
-        self.assertEqual(metadata.description, "xxx")
-        self.assertEqual(metadata.download_url, 'http://example.com')
-        self.assertEqual(metadata.keywords, ['one', 'two'])
-        self.assertEqual(metadata.platforms, None)
-        self.assertEqual(metadata.obsoletes, None)
-        self.assertEqual(metadata.requires, ['foo'])
+        assert metadata.name == "package"
+        assert metadata.version == "1.0"
+        assert metadata.description == "xxx"
+        assert metadata.download_url == 'http://example.com'
+        assert metadata.keywords == ['one', 'two']
+        assert metadata.platforms is None
+        assert metadata.obsoletes is None
+        assert metadata.requires == ['foo']
